@@ -201,7 +201,7 @@ func TestLoadConfigDir(t *testing.T) {
 				primariesWant[i] = f.Body.MissingItemRange().Filename
 			}
 			if diff := cmp.Diff(primaries, primariesWant); diff != "" {
-				t.Errorf(diff)
+				t.Errorf("diff: %s", diff)
 			}
 
 			overrides := map[string]string{}
@@ -213,11 +213,11 @@ func TestLoadConfigDir(t *testing.T) {
 				overridesWant[i] = f.Body.MissingItemRange().Filename
 			}
 			if diff := cmp.Diff(overrides, overridesWant); diff != "" {
-				t.Errorf(diff)
+				t.Errorf("diff: %s", diff)
 			}
 
 			if diff := cmp.Diff(mod.Sources, test.want.Sources); diff != "" {
-				t.Errorf(diff)
+				t.Errorf("diff: %s", diff)
 			}
 
 			files := []string{}
@@ -230,7 +230,7 @@ func TestLoadConfigDir(t *testing.T) {
 			}
 			opt := cmpopts.SortSlices(func(x, y string) bool { return x > y })
 			if diff := cmp.Diff(files, filesWant, opt); diff != "" {
-				t.Errorf(diff)
+				t.Errorf("diff: %s", diff)
 			}
 		})
 	}
@@ -343,7 +343,7 @@ func TestLoadConfigDirFiles(t *testing.T) {
 				got = append(got, name)
 			}
 			if diff := cmp.Diff(got, test.want, opt); diff != "" {
-				t.Errorf(diff)
+				t.Errorf("diff: %s", diff)
 			}
 		})
 	}
@@ -487,3 +487,47 @@ func TestIsConfigDir(t *testing.T) {
 		})
 	}
 }
+
+func TestExists(t *testing.T) {
+	tests := []struct {
+		name  string
+		files map[string]string
+		path  string
+		want  bool
+	}{
+		{
+			name: "exists",
+			files: map[string]string{
+				"foo": "",
+			},
+			path: "foo",
+			want: true,
+		},
+		{
+			name: "not exists",
+			files: map[string]string{
+				"foo": "",
+			},
+			path: "bar",
+			want: false,
+		},
+	}
+
+	for _, test := range tests {
+		t.Run(test.name, func(t *testing.T) {
+			fs := afero.Afero{Fs: afero.NewMemMapFs()}
+			for name, content := range test.files {
+				if err := fs.WriteFile(name, []byte(content), os.ModePerm); err != nil {
+					t.Fatal(err)
+				}
+			}
+			parser := NewParser(fs)
+
+			got := parser.Exists(test.path)
+
+			if got != test.want {
+				t.Errorf("want=%t, got=%t", test.want, got)
+			}
+		})
+	}
+}
